import { IsNotEmpty, IsOptional } from 'class-validator';
import { ApiProperty } from '@nestjs/swagger';
import { ConstraintDto } from './constraint.dto';
import { ArrivalRouteDto } from './arrivalroute.dto';
import { RunwaySpacingDto } from './runwayspacing.dto';
import { PlanningDto } from './planning.dto';
import { WaypointDto } from '../../generic/dto/waypoint.dto';
import { RunwayDto } from './runway.dto';

export class AirportDto {
  @IsNotEmpty()
  @ApiProperty({
    description: 'The unique ICAO code',
    example: 'EDDB',
  })
  icao: string;

  @IsNotEmpty()
  @ApiProperty({
    description: 'The name of the airport',
    example: 'Berlin Brandenburg',
  })
  name: string;

  @IsNotEmpty()
  @ApiProperty({
    description: 'The flight information region (FIR)',
    example: 'FIR Bremen',
  })
  flightInformationRegion: string;

  @IsNotEmpty()
  @ApiProperty({
    description: 'The airport location',
  })
  location: WaypointDto;

  @IsNotEmpty()
  @ApiProperty({
    description: 'The airport elevation in feet',
  })
  elevation: number;

  @IsNotEmpty()
  @ApiProperty({
    description: 'All possible arrival runways',
  })
  runways: RunwayDto[];

  @IsOptional()
  @ApiProperty({
    description: 'The constraints in upper airspaces',
  })
  upperConstraints: ConstraintDto[];

  @IsNotEmpty()
  @ApiProperty({
    description: 'The different arrival routes with potential constraints',
  })
  arrivalRoutes: ArrivalRouteDto[];

  @IsNotEmpty()
  @ApiProperty({
    description: 'The spacings for the runways',
  })
  spacings: RunwaySpacingDto[];

  @IsNotEmpty()
  @ApiProperty({
    description: 'The planning configuration',
  })
  planning: PlanningDto;

  @IsOptional()
  @ApiProperty({
    description: 'The currently active runways',
    example: '["25L", "25R"]',
  })
  activeRunways: string[];

  @IsOptional()
  @ApiProperty({
    description: 'The active arrival mode',
    example: 'STAGGERED',
  })
  arrivalMode: string;
}
