import { IsNotEmpty, IsOptional } from 'class-validator';
import { ApiProperty } from '@nestjs/swagger';

export class AssignmentDto {
  @IsNotEmpty()
  @ApiProperty({
    description: 'The runway identifier',
    example: '25L',
  })
  runway: string;

  @IsNotEmpty()
  @ApiProperty({
    description: 'The urgency of the assignment (possible: SHALL, SHOULD, MAY)',
    example: 'MAY',
  })
  type: string;

  @IsOptional()
  @ApiProperty({
    description: 'The aircrafts (ICAO codes) that require this assignment',
    example: '[ "A346", "B748" ]',
  })
  aircrafts: string[];

  @IsOptional()
  @ApiProperty({
    description: 'The assigned stands that require this assignment',
    example: '[ "A01", "A02" ]',
  })
  assignedStands: string[];
}
