import { IsNotEmpty, Length, IsInt, Min, Max } from 'class-validator';
import { ApiProperty } from '@nestjs/swagger';

export class AircraftDto {
  @IsNotEmpty()
  @ApiProperty({
    description: 'The ICAO code of the aircraft',
    example: 'A359',
  })
  type: string;

  @IsNotEmpty()
  @ApiProperty({
    description: 'The Wake Turbulence Category (possible: L, M, H, S)',
    example: 'M',
  })
  @Length(1)
  wtc: string;

  @IsNotEmpty()
  @ApiProperty({
    description: 'The Wake Turbulence Category (possible: A, B, C, D, E, F)',
    example: 'C',
  })
  @Length(1)
  wakeRecat: string;

  @IsNotEmpty()
  @ApiProperty({
    description: 'The number of engines',
    example: 2,
  })
  @IsInt()
  @Min(1)
  @Max(6)
  engineCount: number;

  @IsNotEmpty()
  @ApiProperty({
    description: 'The engine type (possible: ELECTRIC, TURBOPROP, JET)',
    example: 'JET',
  })
  engineType: string;
}
