import { IsNotEmpty, IsInt, Min, Max } from 'class-validator';
import { ApiProperty } from '@nestjs/swagger';
import { WaypointDto } from '../../generic/dto/waypoint.dto';

export class PredictedWaypointDto {
  @IsNotEmpty()
  @ApiProperty({
    description: 'The waypoint',
  })
  waypoint: WaypointDto;

  @IsNotEmpty()
  @ApiProperty({
    description: 'The planned altitude',
    example: 23000,
  })
  @IsInt()
  @Min(0)
  @Max(60000)
  altitude: number;

  @IsNotEmpty()
  @ApiProperty({
    description: 'The planned indicated airspeed',
    example: 200,
  })
  @IsInt()
  @Min(0)
  @Max(600)
  indicatedAirspeed: number;

  @IsNotEmpty()
  @ApiProperty({
    description: 'The planned groundspeed',
    example: 500,
  })
  @IsInt()
  @Min(0)
  @Max(800)
  groundspeed: number;

  @IsNotEmpty()
  @ApiProperty({
    description: 'The planned time overhead the waypoint',
    example: 'Wed, 14 Jun 2017 07:00:00z',
  })
  @IsInt()
  plannedOverheadTime: string;
}
