import { Prop, Schema, SchemaFactory } from '@nestjs/mongoose';
import { Document } from 'mongoose';
import { Aircraft, AircraftSchema } from './aircraft.model';
import {
  ControllerInput,
  ControllerInputSchema,
} from './controllerinput.model';
import { FlightState, FlightStateSchema } from './flightstate.model';
import { Planning, PlanningSchema } from './planning.model';

export type InboundDocument = Inbound & Document;

@Schema()
export class Inbound {
  @Prop({
    required: true,
    index: true,
    type: String,
  })
  callsign: string;

  @Prop({
    required: true,
    index: true,
    type: String,
  })
  destination: string;

  @Prop({
    required: true,
    type: String,
    enum: ['UNK', 'DEL', 'GND', 'TWR', 'APP', 'DEP', 'CTR'],
  })
  reporter: string;

  @Prop({
    required: true,
    type: AircraftSchema,
  })
  aircraft: Aircraft;

  @Prop({
    required: true,
    type: FlightStateSchema,
  })
  flightState: FlightState;

  @Prop({
    type: ControllerInputSchema,
  })
  controllerData: ControllerInput;

  @Prop({
    type: PlanningSchema,
  })
  plan: Planning;
}

export const InboundSchema = SchemaFactory.createForClass(Inbound);
